@@ -1,13 +1,20 @@
 /*******************************************************************************************
 *
-*   raylib [models] example - loading gltf
+*   raylib [models] example - loading gltf with animations
+*
+*   LIMITATIONS:
+*     - Only supports 1 armature per file, and skips loading it if there are multiple armatures
+*     - Only supports linear interpolation (default method in Blender when checked 
+*       "Always Sample Animations" when exporting a GLTF file)
+*     - Only supports translation/rotation/scale animation channel.path, 
+*       weights not considered (i.e. morph targets)
 *
 *   Example originally created with raylib 3.7, last time updated with raylib 4.2
 *
 *   Example licensed under an unmodified zlib/libpng license, which is an OSI-certified,
 *   BSD-like license that allows static linking with closed source software
 *
-*   Copyright (c) 2020-2022 Ramon Santamaria (@raysan5)
+*   Copyright (c) 2020-2023 Ramon Santamaria (@raysan5)
 *
 ********************************************************************************************/
 
@@ -27,18 +34,24 @@ int main(void)
 
     // Define the camera to look into our 3d world
     Camera camera = { 0 };
-    camera.position = (Vector3){ 10.0f, 10.0f, 10.0f }; // Camera position
-    camera.target = (Vector3){ 0.0f, 0.0f, 0.0f };      // Camera looking at point
+    camera.position = (Vector3){ 5.0f, 5.0f, 5.0f };    // Camera position
+    camera.target = (Vector3){ 0.0f, 2.0f, 0.0f };      // Camera looking at point
     camera.up = (Vector3){ 0.0f, 1.0f, 0.0f };          // Camera up vector (rotation towards target)
     camera.fovy = 45.0f;                                // Camera field-of-view Y
-    camera.projection = CAMERA_PERSPECTIVE;             // Camera mode type
+    camera.projection = CAMERA_PERSPECTIVE;             // Camera projection type
 
-    // Loaf gltf model
+    // Load gltf model
     Model model = LoadModel("resources/models/gltf/robot.glb");
+    
+    // Load gltf model animations
+    unsigned int animsCount = 0;
+    unsigned int animIndex = 0;
+    unsigned int animCurrentFrame = 0;
+    ModelAnimation *modelAnimations = LoadModelAnimations("resources/models/gltf/robot.glb", &animsCount);
 
     Vector3 position = { 0.0f, 0.0f, 0.0f };    // Set model position
 
-    SetCameraMode(camera, CAMERA_FREE); // Set free camera mode
+    DisableCursor();                    // Limit cursor to relative movement inside the window
 
     SetTargetFPS(60);                   // Set our game to run at 60 frames-per-second
     //--------------------------------------------------------------------------------------
@@ -48,22 +61,32 @@ int main(void)
     {
         // Update
         //----------------------------------------------------------------------------------
-        UpdateCamera(&camera);
+        UpdateCamera(&camera, CAMERA_THIRD_PERSON);
+        // Select current animation
+        if (IsKeyPressed(KEY_UP)) animIndex = (animIndex + 1)%animsCount;
+        else if (IsKeyPressed(KEY_DOWN)) animIndex = (animIndex + animsCount - 1)%animsCount;
+        
+        // Update model animation
+        ModelAnimation anim = modelAnimations[animIndex];
+        animCurrentFrame = (animCurrentFrame + 1)%anim.frameCount;
+        UpdateModelAnimation(model, anim, animCurrentFrame);
         //----------------------------------------------------------------------------------
 
         // Draw
         //----------------------------------------------------------------------------------
         BeginDrawing();
 
-            ClearBackground(SKYBLUE);
+            ClearBackground(RAYWHITE);
 
             BeginMode3D(camera);
 
-                DrawModel(model, position, 1.0f, WHITE);
-                DrawGrid(10, 1.0f);         // Draw a grid
+                DrawModel(model, position, 1.0f, WHITE);    // Draw animated model
+                DrawGrid(10, 1.0f);
 
             EndMode3D();
 
+            DrawText("Use the UP/DOWN arrow keys to switch animation", 10, 10, 20, GRAY);
+
         EndDrawing();
         //----------------------------------------------------------------------------------
     }
@@ -71,7 +94,7 @@ int main(void)
     // De-Initialization
     //--------------------------------------------------------------------------------------
     UnloadModel(model);         // Unload model and meshes/material
-    
+
     CloseWindow();              // Close window and OpenGL context
     //--------------------------------------------------------------------------------------
 
